.. image:: https://travis-ci.org/striglia/pyramid_swagger.png?branch=master
  :target: https://travis-ci.org/striglia/pyramid_swagger?branch=master

.. image:: https://coveralls.io/repos/striglia/pyramid_swagger/badge.png
  :target: https://coveralls.io/r/striglia/pyramid_swagger

.. image:: https://landscape.io/github/striglia/pyramid_swagger/master/landscape.png
   :target: https://landscape.io/github/striglia/pyramid_swagger/master

pyramid_swagger
=======================

This project offers convenient tools for using Swagger to define and validate
your interfaces in a Pyramid webapp.

Full documentation is available at http://pyramid-swagger.readthedocs.org/.
